==> haskell-th-lift-0.7.10-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.10
id: th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
key: th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
license: BSD-3-Clause
copyright: © 2006 Ian Lynagh, © 2010-2018 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
author: Ian Lynagh
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
abi: 60d068a969a5d731636a40e25634c1aa
exposed: True
exposed-modules:
    Language.Haskell.TH.Lift
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-lift-0.7.10
hs-libraries: HSth-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-0.7.11-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.11
id: th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
key: th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
license: BSD-3-Clause
copyright: © 2006 Ian Lynagh, © 2010-2018 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
author: Ian Lynagh
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
abi: 3abe31b2134622b7b297c47726ab60c8
exposed: True
exposed-modules:
    Language.Haskell.TH.Lift
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-lift-0.7.11
hs-libraries: HSth-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=4938497122b3b44bd39134a6de0cb043
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
